@@ -13,7 +13,10 @@
 #include <memory>
 namespace KWeatherCore
 {
+Q_NAMESPACE_EXPORT(KWEATHERCORE_EXPORT)
 enum class WindDirection { N, NW, W, SW, S, SE, E, NE };
+Q_ENUM_NS(WindDirection)
+
 /**
  * @short Class represents weatherforecast in a hour
  *
@@ -26,18 +29,19 @@ enum class WindDirection { N, NW, W, SW, S, SE, E, NE };
 class KWEATHERCORE_EXPORT HourlyWeatherForecast
 {
     Q_GADGET
-    Q_PROPERTY(QDateTime date READ date WRITE setDate)
-    Q_PROPERTY(QString weatherDescription READ weatherDescription WRITE setWeatherDescription)
-    Q_PROPERTY(QString weatherIcon READ weatherIcon WRITE setWeatherIcon)
-    Q_PROPERTY(QString neutralWeatherIcon READ neutralWeatherIcon WRITE setNeutralWeatherIcon)
-    Q_PROPERTY(QString windDirection READ windDirectionStr WRITE setWindDirectionStr)
-    Q_PROPERTY(qreal temperature READ temperature WRITE setTemperature)
-    Q_PROPERTY(qreal pressure READ pressure WRITE setPressure)
-    Q_PROPERTY(qreal windSpeed READ windSpeed WRITE setWindSpeed)
-    Q_PROPERTY(qreal humidity READ humidity WRITE setHumidity)
-    Q_PROPERTY(qreal fog READ fog WRITE setFog)
-    Q_PROPERTY(qreal uvIndex READ uvIndex WRITE setUvIndex)
-    Q_PROPERTY(qreal precipitationAmount READ precipitationAmount WRITE setPrecipitationAmount)
+    Q_PROPERTY(QDateTime date READ date)
+    Q_PROPERTY(QString weatherDescription READ weatherDescription)
+    Q_PROPERTY(QString weatherIcon READ weatherIcon)
+    Q_PROPERTY(QString neutralWeatherIcon READ neutralWeatherIcon)
+    Q_PROPERTY(double windDirectionDegree READ windDirectionDegree)
+    Q_PROPERTY(KWeatherCore::WindDirection windDirectionCardinal READ windDirectionCardinal STORED false)
+    Q_PROPERTY(qreal temperature READ temperature)
+    Q_PROPERTY(qreal pressure READ pressure)
+    Q_PROPERTY(qreal windSpeed READ windSpeed)
+    Q_PROPERTY(qreal humidity READ humidity)
+    Q_PROPERTY(qreal fog READ fog)
+    Q_PROPERTY(qreal uvIndex READ uvIndex)
+    Q_PROPERTY(qreal precipitationAmount READ precipitationAmount)
 public:
     /**
      * HourlyWeatherForecast construct a null forecast
@@ -55,7 +59,7 @@ public:
     /**
      * construct from QJsonObject
      */
-    static HourlyWeatherForecast fromJson(QJsonObject obj);
+    static HourlyWeatherForecast fromJson(const QJsonObject &obj);
     /**
      * date of the forecast
      * @return
@@ -114,21 +118,23 @@ public:
      */
     void setPressure(double pressure);
     /**
-     * scoped enum
+     * Wind direction in degree.
+     * That is, the direction the wind is coming from.
+     * @see https://en.wikipedia.org/wiki/Wind_direction
+     * @see windDirectionCardinal
      */
-    WindDirection windDirection() const;
+    double windDirectionDegree() const;
     /**
-     * WindDirection in string. eg. NW
+     * Sets the wind direction in degree.
+     * @see windDirectionDegree
      */
-    QString windDirectionStr() const;
+    void setWindDirectionDegree(double windDirection);
     /**
-     * set wind direction
+     * Cardinal wind direction.
+     * That is, the cardinal direction the wind is coming from.
+     * @see windDirectionDegree
      */
-    void setWindDirection(WindDirection windDirection);
-    /**
-     * set wind direction, QString version
-     */
-    void setWindDirectionStr(const QString &windDirection);
+    WindDirection windDirectionCardinal() const;
     /**
      * wind speed in km/h
      */
