@@ -12,11 +12,11 @@
 #include <QDir>
 #include <QString>
 
-#include "alertinfo.h"
+#include "capalertinfo.h"
+#include "caparea.h"
 
 namespace KWeatherCore
 {
-using Polygon = std::vector<std::pair<float, float>>;
 
 // weather description
 struct ResolvedWeatherDesc {
@@ -32,16 +32,16 @@ struct ResolvedWeatherDesc {
 class KWeatherCorePrivate
 {
 public:
-    static Polygon stringToPolygon(const QString &str);
+    static CAPPolygon stringToPolygon(const QString &str);
     static QString toFixedString(double num);
     static QDir getCacheDirectory(double latitude, double longitude);
 
-    static AlertInfo::Urgency urgencyStringToEnum(const QString &str);
-    static AlertInfo::Severity severityStringToEnum(const QString &str);
-    static AlertInfo::Certainty certaintyStringToEnum(const QString &str);
-    static QString urgencyToString(AlertInfo::Urgency urgency);
-    static QString severityToString(AlertInfo::Severity severity);
-    static QString certaintyToString(AlertInfo::Certainty certainty);
+    static CAPAlertInfo::Urgency urgencyStringToEnum(const QString &str);
+    static CAPAlertInfo::Severity severityStringToEnum(const QString &str);
+    static CAPAlertInfo::Certainty certaintyStringToEnum(const QString &str);
+    static QString urgencyToString(CAPAlertInfo::Urgency urgency);
+    static QString severityToString(CAPAlertInfo::Severity severity);
+    static QString certaintyToString(CAPAlertInfo::Certainty certainty);
 
     static int weatherIconPriorityRank(const QString &icon);
     static ResolvedWeatherDesc resolveAPIWeatherDesc(const QString &desc);
