@@ -5,13 +5,13 @@
  */
 #pragma once
 
-#include "alertentry.h"
 #include "reply.h"
 
 class QNetworkReply;
 
 namespace KWeatherCore
 {
+class CAPAlertMessage;
 class PendingCAPPrivate;
 /**
  * @short The PendingAlerts class contains the reply to an asynchronous
@@ -25,14 +25,14 @@ class KWEATHERCORE_EXPORT PendingCAP : public Reply
 {
     Q_OBJECT
 public:
-    ~PendingCAP();
+    ~PendingCAP() override;
 
     /**
      * value pointer to the shared alerts data
      * the pointer is nullptr until finished() raised
      * @return
      */
-    std::unique_ptr<AlertEntry> value() const;
+    CAPAlertMessage value() const;
 
 private:
     friend class AlertFeedEntry;
